arXivDaily arXiv每日学术速递 周一至周五更新
arXiv周末暂无论文更新,休息一下吧,周末愉快~~
arXiv 2201.00241cs.MScs.CE
收藏

约化空间方法的批处理二阶伴随灵敏度

Batched Second-Order Adjoint Sensitivity for Reduced Space Methods

François Pacaud, Michel Schanen, Daniel Adrian Maldonado, Alexis Montoison, Valentin Churavy, Julian Samaroo, Mihai Anitescu

摘要:

提出了一种在图形处理器(GPU)主导的计算机系统上从隐式非线性方程组中提取二阶灵敏度的有效方法。我们设计了一个自定义的自动微分(AutoDiff)后端,目标是高度并行的体系结构,通过批量提取二阶信息。当非线性方程组与一个缩减空间优化问题相关联时,我们利用批处理伴随-伴随算法中的并行反向模式累积来有效地计算问题的缩减Hessian。我们应用该方法来提取减少Hessian相关的电力网络的平衡方程,并显示在最大的情况下,并行GPU的实现是30倍的速度比基于UMPPACK的顺序CPU参考。

英文摘要:

This paper presents an efficient method for extracting the second-order sensitivities from a system of implicit nonlinear equations on upcoming graphical processing units (GPU) dominated computer systems. We design a custom automatic differentiation (AutoDiff) backend that targets highly parallel architectures by extracting the second-order information in batch. When the nonlinear equations are associated to a reduced space optimization problem, we leverage the parallel reverse-mode accumulation in a batched adjoint-adjoint algorithm to compute efficiently the reduced Hessian of the problem. We apply the method to extract the reduced Hessian associated to the balance equations of a power network, and show on the largest instances that a parallel GPU implementation is 30 times faster than a sequential CPU reference based on UMFPACK.

机构、总结、中文摘要均由AI分析而来,可能存在错误,请以论文正文为准。

↑